/*
 * Copyright 2010 Nathanaël Cottin - http://www.ezjson.org
 *
 * This file is part of EZ JSON (easy JSON integration).
 *
 * EZ JSON is free software: you can redistribute it and/or modify it under the
 * terms of the Lesser GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or any later version.
 *
 * EZ JSON is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Insane. If not, see <http://www.gnu.org/licenses/>.
 */
package org.ezjson;

/**
 * A JSON boolean represents a boolean value. This JSON type is not officially
 * part of the JSON specification but provided for practical reasons
 *
 * @author ncottin
 */
public final class JSONBoolean implements JSONValue {

    private boolean value = false;

    /**
     * Creates a JSON boolean with initial value set to <tt>false</tt>
     */
    public JSONBoolean() {}

    /**
     * Creates and initializes a JSON boolean with an initial value
     *
     * @param value The initial value
     */
    public JSONBoolean(boolean value) {
        setValue(value);
    }

    public boolean getValue() {
        return value;
    }

    public void setValue(boolean value) {
        this.value = value;
    }
}