/*
 * Copyright 2010 Nathanaël Cottin - http://www.ezjson.org
 *
 * This file is part of EZ JSON (easy JSON integration).
 *
 * EZ JSON is free software: you can redistribute it and/or modify it under the
 * terms of the Lesser GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or any later version.
 *
 * EZ JSON is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Insane. If not, see <http://www.gnu.org/licenses/>.
 */
package org.ezjson;

/**
 * A JSON integer is a kind of JSON number which holds an integer value. It is
 * not defined by the JSON specification but has a programmatical interest
 *
 * @author ncottin
 */
public final class JSONInteger implements JSONNumber {

    private int value = 0;

    /**
     * Creates a JSON integer with initial value set to <tt>0</tt>
     */
    public JSONInteger() {}

    public JSONInteger(int value) {
        setValue(value);
    }

    /**
     * Indicates that the internal value is limited to an integer value
     * (i&#46;e&#46; decimals are not allowed)
     *
     * @return <tt>true</tt>
     */
    @Override
    public boolean isInteger() {
        return true;
    }

    public int getValue() {
        return value;
    }

    public void setValue(int value) {
        this.value = value;
    }
}