/*
 * Copyright 2010 Nathanaël Cottin - http://www.ezjson.org
 *
 * This file is part of EZ JSON (easy JSON integration).
 *
 * EZ JSON is free software: you can redistribute it and/or modify it under the
 * terms of the Lesser GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or any later version.
 *
 * EZ JSON is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Insane. If not, see <http://www.gnu.org/licenses/>.
 */
package org.ezjson;

/**
 * A JSON string which conforms to the JSON specification
 * 
 * @author ncottin
 */
public final class JSONString implements JSONValue {

    private String value = null;

    /**
     * Creates a JSON string with a <tt>null</tt> internal value
     */
    public JSONString() {}

    /**
     * Creates and initializes a JSON string with an initial value
     *
     * @param value The possibly <tt>null</tt> initial value
     */
    public JSONString(String value) {
        setValue(value);
    }

    public String getValue() {
        return value;
    }

    public void setValue(String value) {
        this.value = value;
    }
}